#!/usr/bin/env bash
  echo "********************************** Running Step 06 **********************************"
  # Set e will force exit if any error happen or any thread returns other than 0 return
  set -e

  DateTime=$(date '+%d/%m/%Y %H:%M:%S');
  Step_Name=$(basename -- "$0");
  # lookup the account ID
  Account_Id=$(jq -rc .Resources.AccountIds.AccountId Account_Config.json)
  if [ -z $Account_Id ]; then
   echo "Account ID lookup Failed"  | tee -a Error_Log.txt
   exit 1
  fi

  #Pull Path to main folder
  PathToMainFolder=$(jq -rc .Resources.PathToFolder.Path Account_Config.json)

  if [ -z $PathToMainFolder ]; then
   echo "Path to main folder has not been setup. Please setup in Account_Config.json"  | tee -a Error_Log.txt
   exit 1
  fi

  AMS_RFC=$(aws amscm create-rfc --cli-input-json file://"$PathToMainFolder""/CloudhealthPolicy.json" --execution-parameters file://"$PathToMainFolder""/Step06_CreateCloudHealthRoleParams.json" --output json)
  echo "$AMS_RFC" > RFC_ID_Temp.json
  AMS_RFC_ID=$(jq -rc .RfcId RFC_ID_Temp.json)
  #echo ${#AMS_RFC_ID}

  # Check if the length of the return is larger than 20 which means an RFC has been created.
  if [ ${#AMS_RFC_ID} -ge 20 ]; then
    echo "Cloud Health RFC created successfully"
    RFC_Status=$(aws amscm get-rfc --rfc-id $AMS_RFC_ID --output text)
        if (RFC_Status="Editing" ); then
            echo "Cloud Health RFC Ready for Submission"
            RFC_Submit_Status=$(aws amscm submit-rfc --rfc-id $AMS_RFC_ID --output text)
        fi
    echo  $Step_Name "Ran account inflation on AMS managed account " "**"$Account_Id"**" "using RFC," "**"$AMS_RFC_ID"**" ",on" "**"$DateTime"**" | tee -a Account_Onboarding_Report.txt
    echo "RFC to create Cloud-health Role has been submitted" | tee -a Account_Onboarding_Report.txt
  fi

  if [ ${#AMS_RFC_ID} -le 20 ]; then
    echo "Cloud-Health RFC Creation Failed, Exiting" | tee -a Error_Log.txt
    exit 1
  fi

  # Print last command status
  echo $?